@@ -21,6 +21,7 @@ import java.security.NoSuchAlgorithmException;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
+import java.util.concurrent.TimeUnit;
 import java.util.function.BiFunction;
 
 import javax.net.ssl.SSLContext;
@@ -320,6 +321,29 @@ public class RestClientTest {
         Assert.assertNull(client.getAuthContext());
     }
 
+    @SneakyThrows
+    @Test
+    public void testBuilderCallback() {
+        // default configs
+        MockRestClientImpl restClient = new MockRestClientImpl(TEST_URL,
+                                                               RestClientConfig.builder().build());
+        OkHttpClient okHttpClient = Whitebox.getInternalState(restClient, "client");
+        Assert.assertEquals(okHttpClient.connectTimeoutMillis(), 10000);
+        Assert.assertEquals(okHttpClient.readTimeoutMillis(), 10000);
+
+        // set config by (user)builderCallback
+        RestClientConfig config = RestClientConfig.builder().builderCallback(
+                builder -> builder.connectTimeout(5, TimeUnit.SECONDS)
+                                  .readTimeout(30, TimeUnit.SECONDS))
+                                  .build();
+
+        restClient = new MockRestClientImpl(TEST_URL, config);
+        okHttpClient = Whitebox.getInternalState(restClient, "client");
+
+        Assert.assertEquals(okHttpClient.connectTimeoutMillis(), 5000);
+        Assert.assertEquals(okHttpClient.readTimeoutMillis(), 30000);
+    }
+
     @SneakyThrows
     @Test
     public void testRequest() {
@@ -485,6 +509,10 @@ public class RestClientTest {
             super(url, timeout);
         }
 
+        public MockRestClientImpl(String url, RestClientConfig config) {
+            super(url, config);
+        }
+
         @Override
         protected void checkStatus(Response response, int... statuses) {
             // pass
